@@ -21,9 +21,7 @@ def test_simple_freelinks():
     environ = { 'tiddlyweb.config': { 'markdown.wiki_link_base': '' } }
     output = render(tiddler, environ)
 
-    assert '[[Foo [] Bar]]' not in output
-    assert '<a class="wikilink" href="Foo%20%5B%5D%20Bar">Foo [] Bar</a>' in output
-    assert output == '<p>lorem <a class="wikilink" href="Foo%20%5B%5D%20Bar">Foo [] Bar</a> ipsum</p>'
+    assert '[[Foo [] Bar]]' in output
 
 
 def test_spacing():
@@ -69,9 +67,7 @@ def test_labeled_freelinks():
     environ = { 'tiddlyweb.config': { 'markdown.wiki_link_base': '' } }
     output = render(tiddler, environ)
 
-    assert '[[hello [] world|Foo]]' not in output
-    assert '<a class="wikilink" href="Foo">hello [] world</a>' in output
-    assert output == '<p>lorem <a class="wikilink" href="Foo">hello [] world</a> ipsum</p>'
+    assert '[[hello [] world|Foo]]' in output
 
 
 def test_precedence():
@@ -106,3 +102,38 @@ def test_precedence_in_markdown_link():
     tiddler.text = 'I see [foo LoremIpsum bar](http://example.org) you'
     output = render(tiddler, environ)
     assert output == '<p>I see <a href="http://example.org">foo LoremIpsum bar</a> you</p>'
+
+def test_freelink_with_spacelink():
+    # a freelink followed by a spacelink will get confused
+    tiddler = Tiddler('Bar')
+    environ = { 'tiddlyweb.config': {
+        'markdown.wiki_link_base': '',
+        'server_host': {
+            'scheme': 'http',
+            'host': 'tiddlyspace.com',
+            'port': '80'
+            }
+        } }
+    tiddler.text = 'I see [[fire]] and [[rain]] business'
+    output = render(tiddler, environ)
+    assert '>fire<' in output
+    assert '>rain<' in output
+    assert 'href="fire"' in output
+    assert 'href="rain"' in output
+
+    tiddler.text = 'I see [[fire]]@monkey and [[rain]]@monkey business'
+    output = render(tiddler, environ)
+    assert 'href="http://monkey.tiddlyspace.com/fire"' in output
+    assert 'href="http://monkey.tiddlyspace.com/rain"' in output
+
+    tiddler.text = 'I see [[fire]] and [[rain]]@monkey business'
+    output = render(tiddler, environ)
+    assert '>fire<' in output
+    assert 'href="fire"' in output
+    assert 'href="http://monkey.tiddlyspace' in output
+
+    tiddler.text = 'I see [[rain]]@monkey and [[fire]] business'
+    output = render(tiddler, environ)
+    assert '>fire<' in output
+    assert 'href="fire"' in output
+    assert 'href="http://monkey.tiddlyspace.com/rain"' in output
